==> seedsui-react-5.7.93.tgz: package/lib/Page/Page.js <==
function _typeof(obj) { "@babel/helpers - typeof"; return _typeof = "function" == typeof Symbol && "symbol" == typeof Symbol.iterator ? function (obj) { return typeof obj; } : function (obj) { return obj && "function" == typeof Symbol && obj.constructor === Symbol && obj !== Symbol.prototype ? "symbol" : typeof obj; }, _typeof(obj); }
var _excluded = ["animation", "titlebarVisible", "children"];
function ownKeys(object, enumerableOnly) { var keys = Object.keys(object); if (Object.getOwnPropertySymbols) { var symbols = Object.getOwnPropertySymbols(object); enumerableOnly && (symbols = symbols.filter(function (sym) { return Object.getOwnPropertyDescriptor(object, sym).enumerable; })), keys.push.apply(keys, symbols); } return keys; }
function _objectSpread(target) { for (var i = 1; i < arguments.length; i++) { var source = null != arguments[i] ? arguments[i] : {}; i % 2 ? ownKeys(Object(source), !0).forEach(function (key) { _defineProperty(target, key, source[key]); }) : Object.getOwnPropertyDescriptors ? Object.defineProperties(target, Object.getOwnPropertyDescriptors(source)) : ownKeys(Object(source)).forEach(function (key) { Object.defineProperty(target, key, Object.getOwnPropertyDescriptor(source, key)); }); } return target; }
function _defineProperty(obj, key, value) { key = _toPropertyKey(key); if (key in obj) { Object.defineProperty(obj, key, { value: value, enumerable: true, configurable: true, writable: true }); } else { obj[key] = value; } return obj; }
function _toPropertyKey(arg) { var key = _toPrimitive(arg, "string"); return _typeof(key) === "symbol" ? key : String(key); }
function _toPrimitive(input, hint) { if (_typeof(input) !== "object" || input === null) return input; var prim = input[Symbol.toPrimitive]; if (prim !== undefined) { var res = prim.call(input, hint || "default"); if (_typeof(res) !== "object") return res; throw new TypeError("@@toPrimitive must return a primitive value."); } return (hint === "string" ? String : Number)(input); }
function _objectWithoutProperties(source, excluded) { if (source == null) return {}; var target = _objectWithoutPropertiesLoose(source, excluded); var key, i; if (Object.getOwnPropertySymbols) { var sourceSymbolKeys = Object.getOwnPropertySymbols(source); for (i = 0; i < sourceSymbolKeys.length; i++) { key = sourceSymbolKeys[i]; if (excluded.indexOf(key) >= 0) continue; if (!Object.prototype.propertyIsEnumerable.call(source, key)) continue; target[key] = source[key]; } } return target; }
function _objectWithoutPropertiesLoose(source, excluded) { if (source == null) return {}; var target = {}; var sourceKeys = Object.keys(source); var key, i; for (i = 0; i < sourceKeys.length; i++) { key = sourceKeys[i]; if (excluded.indexOf(key) >= 0) continue; target[key] = source[key]; } return target; }
import React, { forwardRef } from 'react';
import Device from "./../Device";
import Header from "./../Header";
import Titlebar from "./../Titlebar";

/**
 * @deprecated since version 5.4.9
 * 请使用Layout
 */
import { jsx as _jsx } from "react/jsx-runtime";
import { jsxs as _jsxs } from "react/jsx-runtime";
var Page = /*#__PURE__*/forwardRef(function (_ref, ref) {
  var animation = _ref.animation,
    _ref$titlebarVisible = _ref.titlebarVisible,
    titlebarVisible = _ref$titlebarVisible === void 0 ? 'auto' : _ref$titlebarVisible,
    children = _ref.children,
    props = _objectWithoutProperties(_ref, _excluded);
  // 支持根据标题自动渲染Titlebar
  var titleText = Device.getUrlParameter('showTitlebar');
  if (titlebarVisible === 'auto') {
    // URL中包含titlebar参数显示
    // eslint-disable-next-line
    titlebarVisible = window.location.href.indexOf('?showTitlebar=') !== -1 || window.location.href.indexOf('&showTitlebar=') !== -1;

    // 全局配置显示
    if (window.__SeedsUI_config__ && Object.prototype.toString.call(window.__SeedsUI_config__) === '[object Object]') {
      var _window$__SeedsUI_con, _window$__SeedsUI_con2;
      if ((_window$__SeedsUI_con = window.__SeedsUI_config__) !== null && _window$__SeedsUI_con !== void 0 && (_window$__SeedsUI_con2 = _window$__SeedsUI_con.Titlebar) !== null && _window$__SeedsUI_con2 !== void 0 && _window$__SeedsUI_con2.titlebarVisible) {
        // eslint-disable-next-line
        titlebarVisible = true;
      }
    }
  }
  return /*#__PURE__*/_jsxs("section", _objectSpread(_objectSpread({
    ref: ref
  }, props), {}, {
    className: 'page' + (props.className ? ' ' + props.className : ''),
    "data-animation": animation,
    children: [titlebarVisible ? /*#__PURE__*/_jsx(Header, {
      children: /*#__PURE__*/_jsx(Titlebar, {
        caption: decodeURIComponent(decodeURIComponent(titleText || ''))
      })
    }) : null, children]
  }));
});
export default Page;

==> seedsui-react-5.8.44.tgz: package/lib/Page/Page.js <==
var _excluded = ["animation", "titlebarVisible", "children"];
function _extends() { _extends = Object.assign ? Object.assign.bind() : function (target) { for (var i = 1; i < arguments.length; i++) { var source = arguments[i]; for (var key in source) { if (Object.prototype.hasOwnProperty.call(source, key)) { target[key] = source[key]; } } } return target; }; return _extends.apply(this, arguments); }
function _objectWithoutProperties(source, excluded) { if (source == null) return {}; var target = _objectWithoutPropertiesLoose(source, excluded); var key, i; if (Object.getOwnPropertySymbols) { var sourceSymbolKeys = Object.getOwnPropertySymbols(source); for (i = 0; i < sourceSymbolKeys.length; i++) { key = sourceSymbolKeys[i]; if (excluded.indexOf(key) >= 0) continue; if (!Object.prototype.propertyIsEnumerable.call(source, key)) continue; target[key] = source[key]; } } return target; }
function _objectWithoutPropertiesLoose(source, excluded) { if (source == null) return {}; var target = {}; var sourceKeys = Object.keys(source); var key, i; for (i = 0; i < sourceKeys.length; i++) { key = sourceKeys[i]; if (excluded.indexOf(key) >= 0) continue; target[key] = source[key]; } return target; }
import React, { forwardRef } from 'react';
import Device from "./../Device";
import Header from "./../Header";
import Titlebar from "./../Titlebar";

/**
 * @deprecated since version 5.4.9
 * 请使用Layout
 */
var Page = /*#__PURE__*/forwardRef(function (_ref, ref) {
  var animation = _ref.animation,
    _ref$titlebarVisible = _ref.titlebarVisible,
    titlebarVisible = _ref$titlebarVisible === void 0 ? 'auto' : _ref$titlebarVisible,
    children = _ref.children,
    props = _objectWithoutProperties(_ref, _excluded);
  // 支持根据标题自动渲染Titlebar
  var titleText = Device.getUrlParameter('showTitlebar');
  if (titlebarVisible === 'auto') {
    // URL中包含titlebar参数显示
    // eslint-disable-next-line
    titlebarVisible = window.location.href.indexOf('?showTitlebar=') !== -1 || window.location.href.indexOf('&showTitlebar=') !== -1;

    // 全局配置显示
    if (window.__SeedsUI_config__ && Object.prototype.toString.call(window.__SeedsUI_config__) === '[object Object]') {
      var _window$__SeedsUI_con;
      if ((_window$__SeedsUI_con = window.__SeedsUI_config__) !== null && _window$__SeedsUI_con !== void 0 && (_window$__SeedsUI_con = _window$__SeedsUI_con.Titlebar) !== null && _window$__SeedsUI_con !== void 0 && _window$__SeedsUI_con.titlebarVisible) {
        // eslint-disable-next-line
        titlebarVisible = true;
      }
    }
  }
  return /*#__PURE__*/React.createElement("section", _extends({
    ref: ref
  }, props, {
    className: 'page' + (props.className ? ' ' + props.className : ''),
    "data-animation": animation
  }), titlebarVisible ? /*#__PURE__*/React.createElement(Header, null, /*#__PURE__*/React.createElement(Titlebar, {
    caption: decodeURIComponent(decodeURIComponent(titleText || ''))
  })) : null, children);
});
export default Page;
